@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,13 +20,13 @@ package org.apache.tools.ant.taskdefs.optional.extension;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.StringTokenizer;
 import java.util.jar.Attributes;
 import java.util.jar.Manifest;
 import java.util.stream.Stream;
 
 import org.apache.tools.ant.util.DeweyDecimal;
-import org.apache.tools.ant.util.StringUtils;
 
 /**
  * <p>Utility class that represents either an available "Optional Package"
@@ -53,7 +53,7 @@ public final class Extension {
      * are not required for the library to operate but if present will be used.
      * It is NOT part of the official "Optional Package" specification.
      *
-     * @see <a href="http://java.sun.com/j2se/1.3/docs/guide/extensions/spec.html#dependency">
+     * @see <a href="https://docs.oracle.com/javase/8/docs/technotes/guides/extensions/spec.html#dependency">
      *      Installed extension dependency</a>
      */
     public static final Attributes.Name OPTIONAL_EXTENSION_LIST
@@ -191,7 +191,8 @@ public final class Extension {
             return new Extension[0];
         }
         return Stream
-            .concat(Stream.of(manifest.getMainAttributes()),
+            .concat(Optional.ofNullable(manifest.getMainAttributes())
+                    .map(Stream::of).orElse(Stream.empty()),
                 manifest.getEntries().values().stream())
             .map(attrs -> getExtension("", attrs)).filter(Objects::nonNull)
             .toArray(Extension[]::new);
@@ -476,53 +477,33 @@ public final class Extension {
      */
     @Override
     public String toString() {
-        final String brace = ": ";
+        final String format = "%s: %s%n";
 
-        final StringBuilder sb = new StringBuilder(EXTENSION_NAME.toString());
-        sb.append(brace);
-        sb.append(extensionName);
-        sb.append(StringUtils.LINE_SEP);
+        final StringBuilder sb = new StringBuilder(String.format(format,
+                EXTENSION_NAME, extensionName));
 
         if (null != specificationVersion) {
-            sb.append(SPECIFICATION_VERSION);
-            sb.append(brace);
-            sb.append(specificationVersion);
-            sb.append(StringUtils.LINE_SEP);
+            sb.append(String.format(format, SPECIFICATION_VERSION, specificationVersion));
         }
 
         if (null != specificationVendor) {
-            sb.append(SPECIFICATION_VENDOR);
-            sb.append(brace);
-            sb.append(specificationVendor);
-            sb.append(StringUtils.LINE_SEP);
+            sb.append(String.format(format, SPECIFICATION_VENDOR, specificationVendor));
         }
 
         if (null != implementationVersion) {
-            sb.append(IMPLEMENTATION_VERSION);
-            sb.append(brace);
-            sb.append(implementationVersion);
-            sb.append(StringUtils.LINE_SEP);
+            sb.append(String.format(format, IMPLEMENTATION_VERSION, implementationVersion));
         }
 
         if (null != implementationVendorID) {
-            sb.append(IMPLEMENTATION_VENDOR_ID);
-            sb.append(brace);
-            sb.append(implementationVendorID);
-            sb.append(StringUtils.LINE_SEP);
+            sb.append(String.format(format, IMPLEMENTATION_VENDOR_ID, implementationVendorID));
         }
 
         if (null != implementationVendor) {
-            sb.append(IMPLEMENTATION_VENDOR);
-            sb.append(brace);
-            sb.append(implementationVendor);
-            sb.append(StringUtils.LINE_SEP);
+            sb.append(String.format(format, IMPLEMENTATION_VENDOR, implementationVendor));
         }
 
         if (null != implementationURL) {
-            sb.append(IMPLEMENTATION_URL);
-            sb.append(brace);
-            sb.append(implementationURL);
-            sb.append(StringUtils.LINE_SEP);
+            sb.append(String.format(format, IMPLEMENTATION_URL, implementationURL));
         }
 
         return sb.toString();
